unit prev2_32;
{
  A sample custom preview for QuickReport 2.0
  Last update: March 5th, 1998
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls,qrprntr,quickrpt,qrextra,qrhtml;

type
  TfrmNetScapePreview = class(TForm)
    Panel1: TPanel;
    QRPreview1: TQRPreview;
    btnPrint: TButton;
    btnNextPage: TButton;
    btnPrevPage: TButton;
    btnZoomIn: TButton;
    btnZoomOut: TButton;
    btnClose: TButton;
    procedure btnPrintClick(Sender: TObject);
    procedure btnPrevPageClick(Sender: TObject);
    procedure btnNextPageClick(Sender: TObject);
    procedure btnZoomInClick(Sender: TObject);
    procedure btnZoomOutClick(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormShow(Sender: TObject);
    procedure QRPreview1PageAvailable(Sender: TObject; PageNum: Integer);
    procedure FormCreate(Sender: TObject);
  private
    { Private declarations }
    procedure Init;
  public
    { Public declarations }
    pQuickreport : TQuickRep;
    bPleaseInit : Boolean;
    bCanPrint: boolean;
    sTitle : string;
  end;

var
  frmNetScapePreview: TfrmNetScapePreview;

implementation

{$R *.DFM}

procedure TfrmNetScapePreview.btnPrintClick(Sender: TObject);
begin
  {
     With 2.0j, QuickReport will set the report's tag property to -1 if the
     user cancels the printersetup.  By checking for this value, we can call
     the print method directly from setup if the users selects OK
  }
  with pQuickReport do
  begin
    tag := -1; { Just in case you are using an older version }
    PrinterSetup;
    if tag = 0 then
      print;
  end;
end;

procedure TfrmNetScapePreview.btnPrevPageClick(Sender: TObject);
begin
  Application.ProcessMessages;
  with QRPreview1 do
    if PageNumber > 1 then
      PageNumber := PageNumber - 1;

end;

procedure TfrmNetScapePreview.btnNextPageClick(Sender: TObject);
begin
  Application.ProcessMessages;

  with QRPreview1 do
    if PageNumber < QRPreview1.QRPrinter.PageCount then
      PageNumber := PageNumber + 1;

end;

procedure TfrmNetScapePreview.btnZoomInClick(Sender: TObject);
begin
  Application.ProcessMessages;
  with QRPreview1 do
    Zoom := Zoom + 10;
end;

procedure TfrmNetScapePreview.btnZoomOutClick(Sender: TObject);
begin
  Application.ProcessMessages;
  with QRPreview1 do
    if Zoom > 10 then
      Zoom := Zoom - 10;
end;

procedure TfrmNetScapePreview.btnCloseClick(Sender: TObject);
begin
  Close;
end;

procedure TfrmNetScapePreview.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  { You must clear the preview's qrpinter property}
  QRPreview1.QRPrinter := nil;
  { tell Delphi to free this form automaticly }
  Action := caFree;
end;

procedure TfrmNetScapePreview.FormShow(Sender: TObject);
var
  OffSet: integer;
begin
  { Signal ourselves that we need to update the form }
  bPleaseInit := True;
  { If the caller reports want to disable printing, then it will set}
  { the following boolean to false }
  if not bCanPrint then
  begin
    btnPrint.Enabled := bCanPrint;
    btnPrint.Visible := bCanPrint;

    // Shift the rest of the buttons over to fill the space of the hidden control
    OffSet := btnNextPage.Left - btnPrint.Left;
    btnNextPage.Left := btnNextPage.Left - Offset;
    btnPrevPage.Left := btnPrevPage.Left - Offset;
    btnZoomIn.Left := btnZoomIn.Left - Offset;
    btnZoomOut.Left := btnZoomOut.Left - Offset;
    btnClose.Left := btnClose.Left - Offset;
  end;
end;

procedure TfrmNetScapePreview.Init;
begin
  if bPleaseInit then
  begin
    { Force the preview to come up in the zoom setting that we want}
    QRPreview1.ZoomToFit;

    bPleaseInit := False;
  end;
end;

procedure TfrmNetScapePreview.QRPreview1PageAvailable(Sender: TObject;
  PageNum: Integer);
begin
  Init;

  if PageNum = 1 then
    Caption := QRPreview1.QRPrinter.Title + ' - 1 page'
  else
    Caption := QRPreview1.QRPrinter.Title + ' - ' + IntToStr(PageNum) + ' pages';

  case QRPreview1.QRPrinter.Status of
    mpReady: Caption := Caption + ' READY';
    mpBusy: Caption := Caption + ' BUSY';
    mpFinished: Caption := Caption + ' FINISHED';
  end;

end;

procedure TfrmNetScapePreview.FormCreate(Sender: TObject);
begin
  { We can disable functionality at runtime }
  bCanPrint := True;
end;

end.
